@@ -9,7 +9,7 @@ use DateTime;
 use DateTime::Duration;
 use Time::Crontab;
 
-our $VERSION = '1.02'; # VERSION
+our $VERSION = '1.03'; # VERSION
 
 sub init {
     my ($bot) = @_;
@@ -64,7 +64,7 @@ sub init {
                 repeat => ( ( lc( $m->{type} ) eq 'every' ) ? 1 : 0 ),
                 text   => $m->{text},
                 expr   => $expr,
-                time   => time() + $lapse,
+                time   => ( ($lapse) ? time() + $lapse : undef ),
                 lapse  => $lapse,
             } );
             $bot->store->set( 'reminders' => \@reminders );
@@ -162,7 +162,7 @@ Bot::IRC::X::Reminder - Bot::IRC plugin for scheduling reminders
 
 =head1 VERSION
 
-version 1.02
+version 1.03
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Bot-IRC-X-Reminder.svg)](https://travis-ci.org/gryphonshafer/Bot-IRC-X-Reminder)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Bot-IRC-X-Reminder/badge.png)](https://coveralls.io/r/gryphonshafer/Bot-IRC-X-Reminder)
